# Curvelets

```{toctree}
:maxdepth: 2
:hidden:

self
auto_examples/index.rst
API <source/modules.rst>
```

```{include} ../README.md
:start-after: <!-- SPHINX-START -->
```



## Indices and tables

- {ref}`genindex`
- {ref}`modindex`
- {ref}`search`
